Date: 07 20, 2001 5:00:51 PM

# look

## Purpose

Designate the first lookahead element of a rule. The first node matching the lookahead element or to the right of it will be the locus where the rule matcher continues matching.

## Remarks

lookahead is an alternate form for look.

WARNING: A reduce action such as singler or noop should be used to ensure that the lookahead node and nodes to its right are not included in the current rule reduction.

## Example

## See Also

trigger, Phrase Element Modifiers.